<?php

namespace Tricks\Dashboard;

use Laravel\Nova\Card;

class HelpCard extends Card
{
    public $width = 'full';

    public $component = 'help-card';

    public function __construct(?string $component = null)
    {
        parent::__construct($component);

        $this->withMeta(['elements' => config('nova-dashboard.elements') ?? null]);
    }
}
