<?php

namespace Tricks\Dashboard;

use Laravel\Nova\Card;
use Laravel\Nova\Dashboards\Main as BaseDashboard;

class Main extends BaseDashboard
{
    public function name(): string
    {
        return 'Start';
    }

    /**
     * @return array<int,Card>
     */
    public function cards(): array
    {
        return [
            new HelpCard,
        ];
    }
}
