(()=>{"use strict";var e={744:(e,t)=>{t.Z=(e,t)=>{const n=e.__vccOpts||e;for(const[e,r]of t)n[e]=r;return n}}},t={};function n(r){var o=t[r];if(void 0!==o)return o.exports;var l=t[r]={exports:{}};return e[r](l,l.exports,n),l.exports}(()=>{const e=Vue;var t={class:"flex justify-center items-center"},r={class:"w-full"},o={class:"md:grid md:grid-cols-2"},l={class:"border-r border-b border-gray-200 dark:border-gray-700"},a=["href"];var c={class:"flex p-6"},i={class:"leading-normal mt-3"};const s={name:"DashboardElement",props:{title:String,text:String}};var d=n(744);const m={name:"Dashboard",props:{card:Object},components:{DashboardElement:(0,d.Z)(s,[["render",function(t,n,r,o,l,a){var s=this,d=(0,e.resolveComponent)("Heading");return(0,e.openBlock)(),(0,e.createElementBlock)("div",c,[(0,e.createElementVNode)("div",null,[(0,e.createVNode)(d,{level:3},{default:(0,e.withCtx)((function(){return[(0,e.createTextVNode)((0,e.toDisplayString)(s.title),1)]})),_:1}),(0,e.createElementVNode)("p",i,(0,e.toDisplayString)(this.text),1)])])}]])},methods:{link:function(e){return"/nova/resources/".concat(e)}}},u=(0,d.Z)(m,[["render",function(n,c,i,s,d,m){var u=this,p=(0,e.resolveComponent)("Heading"),v=(0,e.resolveComponent)("DashboardElement"),f=(0,e.resolveComponent)("Card");return(0,e.openBlock)(),(0,e.createElementBlock)("div",t,[(0,e.createElementVNode)("div",r,[(0,e.createVNode)(p,null,{default:(0,e.withCtx)((function(){return c[0]||(c[0]=[(0,e.createTextVNode)("Herzlich Willkommen")])})),_:1}),c[1]||(c[1]=(0,e.createElementVNode)("p",{class:"leading-tight mt-3"}," Hier können Sie die dynamischen Inhalte Ihrer Website selbständig verwalten. ",-1)),(0,e.createVNode)(f,{class:"mt-8"},{default:(0,e.withCtx)((function(){return[(0,e.createElementVNode)("div",o,[((0,e.openBlock)(!0),(0,e.createElementBlock)(e.Fragment,null,(0,e.renderList)(u.card.elements,(function(t){return(0,e.openBlock)(),(0,e.createElementBlock)("div",l,[t.link?((0,e.openBlock)(),(0,e.createElementBlock)("a",{key:0,href:m.link(t.link),class:"no-underline"},[(0,e.createVNode)(v,{title:t.title,text:t.text},null,8,["title","text"])],8,a)):((0,e.openBlock)(),(0,e.createBlock)(v,{key:1,title:t.title,text:t.text},null,8,["title","text"]))])})),256))])]})),_:1})])])}]]);Nova.booting((function(e,t){e.component("help",u)}))})()})();