<template>
  <div class="flex p-6">
    <div>
      <Heading :level="3">{{ this.title }}</Heading>
      <p class="leading-normal mt-3">
        {{ this.text }}
      </p>
    </div>
  </div>
</template>

<script>
export default {
  name: "HelpCardElement",
  props: {
    title: String,
    text: String
  }
}
</script>
